#[repr(C)]pub struct DeviceGetPowerDomainStatusResponse {
pub status: PowerDomainStatus,
}Fields
status: PowerDomainStatusTrait Implementations
Sourceimpl Clone for DeviceGetPowerDomainStatusResponse
impl Clone for DeviceGetPowerDomainStatusResponse
Sourcefn clone(&self) -> DeviceGetPowerDomainStatusResponse
fn clone(&self) -> DeviceGetPowerDomainStatusResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for &'a DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for &'a DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetPowerDomainStatusResponse, DeviceGetPowerDomainStatusResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetPowerDomainStatusResponse, DeviceGetPowerDomainStatusResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetPowerDomainStatusResponse>, ___E> for &'a DeviceGetPowerDomainStatusResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetPowerDomainStatusResponse: Encode<DeviceGetPowerDomainStatusResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetPowerDomainStatusResponse>, ___E> for &'a DeviceGetPowerDomainStatusResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetPowerDomainStatusResponse: Encode<DeviceGetPowerDomainStatusResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceGetPowerDomainStatusResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetPowerDomainStatusResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceGetPowerDomainStatusResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetPowerDomainStatusResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetPowerDomainStatusResponse>, ___E> for DeviceGetPowerDomainStatusResponsewhere
___E: Encoder + ?Sized,
DeviceGetPowerDomainStatusResponse: Encode<DeviceGetPowerDomainStatusResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetPowerDomainStatusResponse>, ___E> for DeviceGetPowerDomainStatusResponsewhere
___E: Encoder + ?Sized,
DeviceGetPowerDomainStatusResponse: Encode<DeviceGetPowerDomainStatusResponse, ___E>,
Sourcefn encode_option(
this: Option<DeviceGetPowerDomainStatusResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetPowerDomainStatusResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceGetPowerDomainStatusResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetPowerDomainStatusResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
impl FromWire<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetPowerDomainStatusResponse, DeviceGetPowerDomainStatusResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetPowerDomainStatusResponse, DeviceGetPowerDomainStatusResponse>
Sourcefn from_wire(
wire: DeviceGetPowerDomainStatusResponse,
) -> DeviceGetPowerDomainStatusResponse
fn from_wire( wire: DeviceGetPowerDomainStatusResponse, ) -> DeviceGetPowerDomainStatusResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
impl FromWireRef<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
Sourcefn from_wire_ref(
wire: &DeviceGetPowerDomainStatusResponse,
) -> DeviceGetPowerDomainStatusResponse
fn from_wire_ref( wire: &DeviceGetPowerDomainStatusResponse, ) -> DeviceGetPowerDomainStatusResponse
Converts the given reference to this type.
Sourceimpl Ord for DeviceGetPowerDomainStatusResponse
impl Ord for DeviceGetPowerDomainStatusResponse
Sourcefn cmp(&self, other: &DeviceGetPowerDomainStatusResponse) -> Ordering
fn cmp(&self, other: &DeviceGetPowerDomainStatusResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetPowerDomainStatusResponse
impl PartialEq for DeviceGetPowerDomainStatusResponse
Sourcefn eq(&self, other: &DeviceGetPowerDomainStatusResponse) -> bool
fn eq(&self, other: &DeviceGetPowerDomainStatusResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetPowerDomainStatusResponse
impl PartialOrd for DeviceGetPowerDomainStatusResponse
impl Copy for DeviceGetPowerDomainStatusResponse
impl Eq for DeviceGetPowerDomainStatusResponse
impl StructuralPartialEq for DeviceGetPowerDomainStatusResponse