#[repr(C)]pub struct DeviceRequestVoltageRequest {
pub voltage: u32,
}Fields
voltage: u32Trait Implementations
Sourceimpl Clone for DeviceRequestVoltageRequest
impl Clone for DeviceRequestVoltageRequest
Sourcefn clone(&self) -> DeviceRequestVoltageRequest
fn clone(&self) -> DeviceRequestVoltageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceRequestVoltageRequest
impl Debug for DeviceRequestVoltageRequest
Sourceimpl<'a, ___E> Encode<DeviceRequestVoltageRequest, ___E> for &'a DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceRequestVoltageRequest, ___E> for &'a DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceRequestVoltageRequest, ___E> for DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceRequestVoltageRequest, ___E> for DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceRequestVoltageRequest>, ___E> for &'a DeviceRequestVoltageRequestwhere
___E: Encoder + ?Sized,
&'a DeviceRequestVoltageRequest: Encode<DeviceRequestVoltageRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceRequestVoltageRequest>, ___E> for &'a DeviceRequestVoltageRequestwhere
___E: Encoder + ?Sized,
&'a DeviceRequestVoltageRequest: Encode<DeviceRequestVoltageRequest, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceRequestVoltageRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceRequestVoltageRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceRequestVoltageRequest>, ___E> for DeviceRequestVoltageRequestwhere
___E: Encoder + ?Sized,
DeviceRequestVoltageRequest: Encode<DeviceRequestVoltageRequest, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceRequestVoltageRequest>, ___E> for DeviceRequestVoltageRequestwhere
___E: Encoder + ?Sized,
DeviceRequestVoltageRequest: Encode<DeviceRequestVoltageRequest, ___E>,
Sourcefn encode_option(
this: Option<DeviceRequestVoltageRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceRequestVoltageRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
impl FromWire<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
Sourcefn from_wire(wire: DeviceRequestVoltageRequest) -> DeviceRequestVoltageRequest
fn from_wire(wire: DeviceRequestVoltageRequest) -> DeviceRequestVoltageRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
impl FromWireRef<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
Sourcefn from_wire_ref(
wire: &DeviceRequestVoltageRequest,
) -> DeviceRequestVoltageRequest
fn from_wire_ref( wire: &DeviceRequestVoltageRequest, ) -> DeviceRequestVoltageRequest
Converts the given reference to this type.
Sourceimpl Hash for DeviceRequestVoltageRequest
impl Hash for DeviceRequestVoltageRequest
Sourceimpl Ord for DeviceRequestVoltageRequest
impl Ord for DeviceRequestVoltageRequest
Sourcefn cmp(&self, other: &DeviceRequestVoltageRequest) -> Ordering
fn cmp(&self, other: &DeviceRequestVoltageRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceRequestVoltageRequest
impl PartialEq for DeviceRequestVoltageRequest
Sourcefn eq(&self, other: &DeviceRequestVoltageRequest) -> bool
fn eq(&self, other: &DeviceRequestVoltageRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceRequestVoltageRequest
impl PartialOrd for DeviceRequestVoltageRequest
impl Copy for DeviceRequestVoltageRequest
impl Eq for DeviceRequestVoltageRequest
impl StructuralPartialEq for DeviceRequestVoltageRequest