#[repr(C)]pub struct DeviceRequestVoltageResponse {
pub actual_voltage: u32,
}Fields
actual_voltage: u32Trait Implementations
Sourceimpl Clone for DeviceRequestVoltageResponse
impl Clone for DeviceRequestVoltageResponse
Sourcefn clone(&self) -> DeviceRequestVoltageResponse
fn clone(&self) -> DeviceRequestVoltageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceRequestVoltageResponse
impl Debug for DeviceRequestVoltageResponse
Sourceimpl<'a, ___E> Encode<DeviceRequestVoltageResponse, ___E> for &'a DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceRequestVoltageResponse, ___E> for &'a DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceRequestVoltageResponse, ___E> for DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceRequestVoltageResponse, ___E> for DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceRequestVoltageResponse>, ___E> for &'a DeviceRequestVoltageResponsewhere
___E: Encoder + ?Sized,
&'a DeviceRequestVoltageResponse: Encode<DeviceRequestVoltageResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceRequestVoltageResponse>, ___E> for &'a DeviceRequestVoltageResponsewhere
___E: Encoder + ?Sized,
&'a DeviceRequestVoltageResponse: Encode<DeviceRequestVoltageResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceRequestVoltageResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceRequestVoltageResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceRequestVoltageResponse>, ___E> for DeviceRequestVoltageResponsewhere
___E: Encoder + ?Sized,
DeviceRequestVoltageResponse: Encode<DeviceRequestVoltageResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceRequestVoltageResponse>, ___E> for DeviceRequestVoltageResponsewhere
___E: Encoder + ?Sized,
DeviceRequestVoltageResponse: Encode<DeviceRequestVoltageResponse, ___E>,
Sourcefn encode_option(
this: Option<DeviceRequestVoltageResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceRequestVoltageResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceRequestVoltageResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
impl FromWire<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
Sourcefn from_wire(wire: DeviceRequestVoltageResponse) -> DeviceRequestVoltageResponse
fn from_wire(wire: DeviceRequestVoltageResponse) -> DeviceRequestVoltageResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
impl FromWireRef<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
Sourcefn from_wire_ref(
wire: &DeviceRequestVoltageResponse,
) -> DeviceRequestVoltageResponse
fn from_wire_ref( wire: &DeviceRequestVoltageResponse, ) -> DeviceRequestVoltageResponse
Converts the given reference to this type.
Sourceimpl Hash for DeviceRequestVoltageResponse
impl Hash for DeviceRequestVoltageResponse
Sourceimpl Ord for DeviceRequestVoltageResponse
impl Ord for DeviceRequestVoltageResponse
Sourcefn cmp(&self, other: &DeviceRequestVoltageResponse) -> Ordering
fn cmp(&self, other: &DeviceRequestVoltageResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceRequestVoltageResponse
impl PartialEq for DeviceRequestVoltageResponse
Sourcefn eq(&self, other: &DeviceRequestVoltageResponse) -> bool
fn eq(&self, other: &DeviceRequestVoltageResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceRequestVoltageResponse
impl PartialOrd for DeviceRequestVoltageResponse
impl Copy for DeviceRequestVoltageResponse
impl Eq for DeviceRequestVoltageResponse
impl StructuralPartialEq for DeviceRequestVoltageResponse