pub struct PowerElement {
pub name: Option<String>,
pub levels: Option<Vec<PowerLevel>>,
}Expand description
Set of PowerLevels and a human-readable identifier. A PowerLevel itself
contains information about valid transitions out of that level.
Fields
name: Option<String>levels: Option<Vec<PowerLevel>>Trait Implementations
Sourceimpl Clone for PowerElement
impl Clone for PowerElement
Sourcefn clone(&self) -> PowerElement
fn clone(&self) -> PowerElement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PowerElement
impl Debug for PowerElement
Sourceimpl Default for PowerElement
impl Default for PowerElement
Sourcefn default() -> PowerElement
fn default() -> PowerElement
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<PowerElement<'static>, ___E> for &'a PowerElementwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<PowerElement<'static>, ___E> for &'a PowerElementwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<PowerElement<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<PowerElement<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PowerElement<'static>, ___E> for PowerElementwhere
___E: Encoder + ?Sized,
impl<___E> Encode<PowerElement<'static>, ___E> for PowerElementwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<PowerElement<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<PowerElement<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<PowerElement<'de>> for PowerElement
impl<'de> FromWire<PowerElement<'de>> for PowerElement
Sourcefn from_wire(wire_: PowerElement<'de>) -> PowerElement
fn from_wire(wire_: PowerElement<'de>) -> PowerElement
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PowerElement<'de>> for PowerElement
impl<'de> FromWireRef<PowerElement<'de>> for PowerElement
Sourcefn from_wire_ref(wire: &PowerElement<'de>) -> PowerElement
fn from_wire_ref(wire: &PowerElement<'de>) -> PowerElement
Converts the given reference to this type.
Sourceimpl Hash for PowerElement
impl Hash for PowerElement
Sourceimpl Ord for PowerElement
impl Ord for PowerElement
Sourcefn cmp(&self, other: &PowerElement) -> Ordering
fn cmp(&self, other: &PowerElement) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PowerElement
impl PartialEq for PowerElement
Sourcefn eq(&self, other: &PowerElement) -> bool
fn eq(&self, other: &PowerElement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PowerElement
impl PartialOrd for PowerElement
impl Eq for PowerElement
impl StructuralPartialEq for PowerElement