pub struct PowerLevel {
pub level: Option<u8>,
pub name: Option<String>,
pub transitions: Option<Vec<Transition>>,
}Expand description
A zero-indexed set of levels that a device can assume.
levelis the zero-indexed level of thisPowerLevel.nameis a human-readable label for thisPowerLevel, used only for debugging.transitionsdescribes the levels that are valid transitions from thisPowerLevel.
Fields
level: Option<u8>name: Option<String>transitions: Option<Vec<Transition>>Trait Implementations
Sourceimpl Clone for PowerLevel
impl Clone for PowerLevel
Sourcefn clone(&self) -> PowerLevel
fn clone(&self) -> PowerLevel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PowerLevel
impl Debug for PowerLevel
Sourceimpl Default for PowerLevel
impl Default for PowerLevel
Sourcefn default() -> PowerLevel
fn default() -> PowerLevel
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<PowerLevel<'static>, ___E> for &'a PowerLevelwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<PowerLevel<'static>, ___E> for &'a PowerLevelwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<PowerLevel<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<PowerLevel<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PowerLevel<'static>, ___E> for PowerLevelwhere
___E: Encoder + ?Sized,
impl<___E> Encode<PowerLevel<'static>, ___E> for PowerLevelwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<PowerLevel<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<PowerLevel<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<PowerLevel<'de>> for PowerLevel
impl<'de> FromWire<PowerLevel<'de>> for PowerLevel
Sourcefn from_wire(wire_: PowerLevel<'de>) -> PowerLevel
fn from_wire(wire_: PowerLevel<'de>) -> PowerLevel
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PowerLevel<'de>> for PowerLevel
impl<'de> FromWireRef<PowerLevel<'de>> for PowerLevel
Sourcefn from_wire_ref(wire: &PowerLevel<'de>) -> PowerLevel
fn from_wire_ref(wire: &PowerLevel<'de>) -> PowerLevel
Converts the given reference to this type.
Sourceimpl Hash for PowerLevel
impl Hash for PowerLevel
Sourceimpl Ord for PowerLevel
impl Ord for PowerLevel
Sourcefn cmp(&self, other: &PowerLevel) -> Ordering
fn cmp(&self, other: &PowerLevel) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PowerLevel
impl PartialEq for PowerLevel
Sourcefn eq(&self, other: &PowerLevel) -> bool
fn eq(&self, other: &PowerLevel) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PowerLevel
impl PartialOrd for PowerLevel
impl Eq for PowerLevel
impl StructuralPartialEq for PowerLevel