#[repr(C)]pub struct DeviceGetCurrentVoltageRequest {
pub index: u32,
}Fields
index: u32Trait Implementations
Sourceimpl Clone for DeviceGetCurrentVoltageRequest
impl Clone for DeviceGetCurrentVoltageRequest
Sourcefn clone(&self) -> DeviceGetCurrentVoltageRequest
fn clone(&self) -> DeviceGetCurrentVoltageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for &'a DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for &'a DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageRequest>, ___E> for &'a DeviceGetCurrentVoltageRequestwhere
___E: Encoder + ?Sized,
&'a DeviceGetCurrentVoltageRequest: Encode<DeviceGetCurrentVoltageRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageRequest>, ___E> for &'a DeviceGetCurrentVoltageRequestwhere
___E: Encoder + ?Sized,
&'a DeviceGetCurrentVoltageRequest: Encode<DeviceGetCurrentVoltageRequest, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceGetCurrentVoltageRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceGetCurrentVoltageRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageRequest>, ___E> for DeviceGetCurrentVoltageRequestwhere
___E: Encoder + ?Sized,
DeviceGetCurrentVoltageRequest: Encode<DeviceGetCurrentVoltageRequest, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageRequest>, ___E> for DeviceGetCurrentVoltageRequestwhere
___E: Encoder + ?Sized,
DeviceGetCurrentVoltageRequest: Encode<DeviceGetCurrentVoltageRequest, ___E>,
Sourcefn encode_option(
this: Option<DeviceGetCurrentVoltageRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceGetCurrentVoltageRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
impl FromWire<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
Sourcefn from_wire(
wire: DeviceGetCurrentVoltageRequest,
) -> DeviceGetCurrentVoltageRequest
fn from_wire( wire: DeviceGetCurrentVoltageRequest, ) -> DeviceGetCurrentVoltageRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
impl FromWireRef<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
Sourcefn from_wire_ref(
wire: &DeviceGetCurrentVoltageRequest,
) -> DeviceGetCurrentVoltageRequest
fn from_wire_ref( wire: &DeviceGetCurrentVoltageRequest, ) -> DeviceGetCurrentVoltageRequest
Converts the given reference to this type.
Sourceimpl Ord for DeviceGetCurrentVoltageRequest
impl Ord for DeviceGetCurrentVoltageRequest
Sourcefn cmp(&self, other: &DeviceGetCurrentVoltageRequest) -> Ordering
fn cmp(&self, other: &DeviceGetCurrentVoltageRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetCurrentVoltageRequest
impl PartialEq for DeviceGetCurrentVoltageRequest
Sourcefn eq(&self, other: &DeviceGetCurrentVoltageRequest) -> bool
fn eq(&self, other: &DeviceGetCurrentVoltageRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetCurrentVoltageRequest
impl PartialOrd for DeviceGetCurrentVoltageRequest
impl Copy for DeviceGetCurrentVoltageRequest
impl Eq for DeviceGetCurrentVoltageRequest
impl StructuralPartialEq for DeviceGetCurrentVoltageRequest