#[repr(C)]pub struct DeviceGetCurrentVoltageResponse {
pub current_voltage: u32,
}Fields
current_voltage: u32Trait Implementations
Sourceimpl Clone for DeviceGetCurrentVoltageResponse
impl Clone for DeviceGetCurrentVoltageResponse
Sourcefn clone(&self) -> DeviceGetCurrentVoltageResponse
fn clone(&self) -> DeviceGetCurrentVoltageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for &'a DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for &'a DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageResponse>, ___E> for &'a DeviceGetCurrentVoltageResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetCurrentVoltageResponse: Encode<DeviceGetCurrentVoltageResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageResponse>, ___E> for &'a DeviceGetCurrentVoltageResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetCurrentVoltageResponse: Encode<DeviceGetCurrentVoltageResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceGetCurrentVoltageResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceGetCurrentVoltageResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageResponse>, ___E> for DeviceGetCurrentVoltageResponsewhere
___E: Encoder + ?Sized,
DeviceGetCurrentVoltageResponse: Encode<DeviceGetCurrentVoltageResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetCurrentVoltageResponse>, ___E> for DeviceGetCurrentVoltageResponsewhere
___E: Encoder + ?Sized,
DeviceGetCurrentVoltageResponse: Encode<DeviceGetCurrentVoltageResponse, ___E>,
Sourcefn encode_option(
this: Option<DeviceGetCurrentVoltageResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceGetCurrentVoltageResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetCurrentVoltageResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
impl FromWire<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
Sourcefn from_wire(
wire: DeviceGetCurrentVoltageResponse,
) -> DeviceGetCurrentVoltageResponse
fn from_wire( wire: DeviceGetCurrentVoltageResponse, ) -> DeviceGetCurrentVoltageResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
impl FromWireRef<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
Sourcefn from_wire_ref(
wire: &DeviceGetCurrentVoltageResponse,
) -> DeviceGetCurrentVoltageResponse
fn from_wire_ref( wire: &DeviceGetCurrentVoltageResponse, ) -> DeviceGetCurrentVoltageResponse
Converts the given reference to this type.
Sourceimpl Ord for DeviceGetCurrentVoltageResponse
impl Ord for DeviceGetCurrentVoltageResponse
Sourcefn cmp(&self, other: &DeviceGetCurrentVoltageResponse) -> Ordering
fn cmp(&self, other: &DeviceGetCurrentVoltageResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetCurrentVoltageResponse
impl PartialEq for DeviceGetCurrentVoltageResponse
Sourcefn eq(&self, other: &DeviceGetCurrentVoltageResponse) -> bool
fn eq(&self, other: &DeviceGetCurrentVoltageResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetCurrentVoltageResponse
impl PartialOrd for DeviceGetCurrentVoltageResponse
impl Copy for DeviceGetCurrentVoltageResponse
impl Eq for DeviceGetCurrentVoltageResponse
impl StructuralPartialEq for DeviceGetCurrentVoltageResponse