#[repr(C)]pub struct DeviceGetSupportedVoltageRangeResponse {
pub min: u32,
pub max: u32,
}Fields
min: u32max: u32Trait Implementations
Sourceimpl Clone for DeviceGetSupportedVoltageRangeResponse
impl Clone for DeviceGetSupportedVoltageRangeResponse
Sourcefn clone(&self) -> DeviceGetSupportedVoltageRangeResponse
fn clone(&self) -> DeviceGetSupportedVoltageRangeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceGetSupportedVoltageRangeResponse, ___E> for &'a DeviceGetSupportedVoltageRangeResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetSupportedVoltageRangeResponse, ___E> for &'a DeviceGetSupportedVoltageRangeResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSupportedVoltageRangeResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSupportedVoltageRangeResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetSupportedVoltageRangeResponse, ___E> for DeviceGetSupportedVoltageRangeResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetSupportedVoltageRangeResponse, ___E> for DeviceGetSupportedVoltageRangeResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSupportedVoltageRangeResponse, DeviceGetSupportedVoltageRangeResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSupportedVoltageRangeResponse, DeviceGetSupportedVoltageRangeResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSupportedVoltageRangeResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSupportedVoltageRangeResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetSupportedVoltageRangeResponse>, ___E> for &'a DeviceGetSupportedVoltageRangeResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetSupportedVoltageRangeResponse: Encode<DeviceGetSupportedVoltageRangeResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetSupportedVoltageRangeResponse>, ___E> for &'a DeviceGetSupportedVoltageRangeResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetSupportedVoltageRangeResponse: Encode<DeviceGetSupportedVoltageRangeResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceGetSupportedVoltageRangeResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSupportedVoltageRangeResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceGetSupportedVoltageRangeResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSupportedVoltageRangeResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetSupportedVoltageRangeResponse>, ___E> for DeviceGetSupportedVoltageRangeResponsewhere
___E: Encoder + ?Sized,
DeviceGetSupportedVoltageRangeResponse: Encode<DeviceGetSupportedVoltageRangeResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetSupportedVoltageRangeResponse>, ___E> for DeviceGetSupportedVoltageRangeResponsewhere
___E: Encoder + ?Sized,
DeviceGetSupportedVoltageRangeResponse: Encode<DeviceGetSupportedVoltageRangeResponse, ___E>,
Sourcefn encode_option(
this: Option<DeviceGetSupportedVoltageRangeResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSupportedVoltageRangeResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceGetSupportedVoltageRangeResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSupportedVoltageRangeResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetSupportedVoltageRangeResponse> for DeviceGetSupportedVoltageRangeResponse
impl FromWire<DeviceGetSupportedVoltageRangeResponse> for DeviceGetSupportedVoltageRangeResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSupportedVoltageRangeResponse, DeviceGetSupportedVoltageRangeResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSupportedVoltageRangeResponse, DeviceGetSupportedVoltageRangeResponse>
Sourcefn from_wire(
wire: DeviceGetSupportedVoltageRangeResponse,
) -> DeviceGetSupportedVoltageRangeResponse
fn from_wire( wire: DeviceGetSupportedVoltageRangeResponse, ) -> DeviceGetSupportedVoltageRangeResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetSupportedVoltageRangeResponse> for DeviceGetSupportedVoltageRangeResponse
impl FromWireRef<DeviceGetSupportedVoltageRangeResponse> for DeviceGetSupportedVoltageRangeResponse
Sourcefn from_wire_ref(
wire: &DeviceGetSupportedVoltageRangeResponse,
) -> DeviceGetSupportedVoltageRangeResponse
fn from_wire_ref( wire: &DeviceGetSupportedVoltageRangeResponse, ) -> DeviceGetSupportedVoltageRangeResponse
Converts the given reference to this type.
Sourceimpl Ord for DeviceGetSupportedVoltageRangeResponse
impl Ord for DeviceGetSupportedVoltageRangeResponse
Sourcefn cmp(&self, other: &DeviceGetSupportedVoltageRangeResponse) -> Ordering
fn cmp(&self, other: &DeviceGetSupportedVoltageRangeResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetSupportedVoltageRangeResponse
impl PartialEq for DeviceGetSupportedVoltageRangeResponse
Sourcefn eq(&self, other: &DeviceGetSupportedVoltageRangeResponse) -> bool
fn eq(&self, other: &DeviceGetSupportedVoltageRangeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetSupportedVoltageRangeResponse
impl PartialOrd for DeviceGetSupportedVoltageRangeResponse
impl Copy for DeviceGetSupportedVoltageRangeResponse
impl Eq for DeviceGetSupportedVoltageRangeResponse
impl StructuralPartialEq for DeviceGetSupportedVoltageRangeResponse