#[repr(C)]pub struct DeviceGetCurrentVoltageRequest {
pub index: Uint32,
}Expand description
The wire type corresponding to DeviceGetCurrentVoltageRequest.
Fields
index: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetCurrentVoltageRequest
impl Clone for DeviceGetCurrentVoltageRequest
Sourcefn clone(&self) -> DeviceGetCurrentVoltageRequest
fn clone(&self) -> DeviceGetCurrentVoltageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetCurrentVoltageRequest
impl Constrained for DeviceGetCurrentVoltageRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetCurrentVoltageRequest>,
_: <DeviceGetCurrentVoltageRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetCurrentVoltageRequest>, _: <DeviceGetCurrentVoltageRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for DeviceGetCurrentVoltageRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetCurrentVoltageRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for &'a DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for &'a DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetCurrentVoltageRequest, ___E> for DeviceGetCurrentVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetCurrentVoltageRequest, ___E> for DeviceGetCurrentVoltageRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetCurrentVoltageRequest, ___E> for DeviceGetCurrentVoltageRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
impl FromWire<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageRequest, DeviceGetCurrentVoltageRequest>
Sourcefn from_wire(
wire: DeviceGetCurrentVoltageRequest,
) -> DeviceGetCurrentVoltageRequest
fn from_wire( wire: DeviceGetCurrentVoltageRequest, ) -> DeviceGetCurrentVoltageRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
impl FromWireRef<DeviceGetCurrentVoltageRequest> for DeviceGetCurrentVoltageRequest
Sourcefn from_wire_ref(
wire: &DeviceGetCurrentVoltageRequest,
) -> DeviceGetCurrentVoltageRequest
fn from_wire_ref( wire: &DeviceGetCurrentVoltageRequest, ) -> DeviceGetCurrentVoltageRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetCurrentVoltageRequest
impl IntoNatural for DeviceGetCurrentVoltageRequest
Sourcetype Natural = DeviceGetCurrentVoltageRequest
type Natural = DeviceGetCurrentVoltageRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetCurrentVoltageRequest
impl Wire for DeviceGetCurrentVoltageRequest
Sourcetype Narrowed<'de> = DeviceGetCurrentVoltageRequest
type Narrowed<'de> = DeviceGetCurrentVoltageRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetCurrentVoltageRequest>)
Writes zeroes to the padding for this type, if any.