#[repr(C)]pub struct DeviceGetCurrentVoltageResponse {
pub current_voltage: Uint32,
}Expand description
The wire type corresponding to DeviceGetCurrentVoltageResponse.
Fields
current_voltage: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetCurrentVoltageResponse
impl Clone for DeviceGetCurrentVoltageResponse
Sourcefn clone(&self) -> DeviceGetCurrentVoltageResponse
fn clone(&self) -> DeviceGetCurrentVoltageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetCurrentVoltageResponse
impl Constrained for DeviceGetCurrentVoltageResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetCurrentVoltageResponse>,
_: <DeviceGetCurrentVoltageResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetCurrentVoltageResponse>, _: <DeviceGetCurrentVoltageResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for DeviceGetCurrentVoltageResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetCurrentVoltageResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for &'a DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for &'a DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetCurrentVoltageResponse, ___E> for DeviceGetCurrentVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetCurrentVoltageResponse, ___E> for DeviceGetCurrentVoltageResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetCurrentVoltageResponse, ___E> for DeviceGetCurrentVoltageResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
impl FromWire<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetCurrentVoltageResponse, DeviceGetCurrentVoltageResponse>
Sourcefn from_wire(
wire: DeviceGetCurrentVoltageResponse,
) -> DeviceGetCurrentVoltageResponse
fn from_wire( wire: DeviceGetCurrentVoltageResponse, ) -> DeviceGetCurrentVoltageResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
impl FromWireRef<DeviceGetCurrentVoltageResponse> for DeviceGetCurrentVoltageResponse
Sourcefn from_wire_ref(
wire: &DeviceGetCurrentVoltageResponse,
) -> DeviceGetCurrentVoltageResponse
fn from_wire_ref( wire: &DeviceGetCurrentVoltageResponse, ) -> DeviceGetCurrentVoltageResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetCurrentVoltageResponse
impl IntoNatural for DeviceGetCurrentVoltageResponse
Sourcetype Natural = DeviceGetCurrentVoltageResponse
type Natural = DeviceGetCurrentVoltageResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetCurrentVoltageResponse
impl Wire for DeviceGetCurrentVoltageResponse
Sourcetype Narrowed<'de> = DeviceGetCurrentVoltageResponse
type Narrowed<'de> = DeviceGetCurrentVoltageResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetCurrentVoltageResponse>)
Writes zeroes to the padding for this type, if any.