#[repr(C)]pub struct DeviceRegisterPowerDomainRequest {
pub min_needed_voltage: Uint32,
pub max_supported_voltage: Uint32,
}Expand description
The wire type corresponding to DeviceRegisterPowerDomainRequest.
Fields
min_needed_voltage: Uint32max_supported_voltage: Uint32Trait Implementations
Sourceimpl Clone for DeviceRegisterPowerDomainRequest
impl Clone for DeviceRegisterPowerDomainRequest
Sourcefn clone(&self) -> DeviceRegisterPowerDomainRequest
fn clone(&self) -> DeviceRegisterPowerDomainRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceRegisterPowerDomainRequest
impl Constrained for DeviceRegisterPowerDomainRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceRegisterPowerDomainRequest>,
_: <DeviceRegisterPowerDomainRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceRegisterPowerDomainRequest>, _: <DeviceRegisterPowerDomainRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for DeviceRegisterPowerDomainRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceRegisterPowerDomainRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceRegisterPowerDomainRequest, ___E> for &'a DeviceRegisterPowerDomainRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceRegisterPowerDomainRequest, ___E> for &'a DeviceRegisterPowerDomainRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceRegisterPowerDomainRequest, ___E> for DeviceRegisterPowerDomainRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceRegisterPowerDomainRequest, ___E> for DeviceRegisterPowerDomainRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRegisterPowerDomainRequest, DeviceRegisterPowerDomainRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRegisterPowerDomainRequest, DeviceRegisterPowerDomainRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<DeviceRegisterPowerDomainRequest, ___E> for DeviceRegisterPowerDomainRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<DeviceRegisterPowerDomainRequest, ___E> for DeviceRegisterPowerDomainRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceRegisterPowerDomainRequest> for DeviceRegisterPowerDomainRequest
impl FromWire<DeviceRegisterPowerDomainRequest> for DeviceRegisterPowerDomainRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRegisterPowerDomainRequest, DeviceRegisterPowerDomainRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRegisterPowerDomainRequest, DeviceRegisterPowerDomainRequest>
Sourcefn from_wire(
wire: DeviceRegisterPowerDomainRequest,
) -> DeviceRegisterPowerDomainRequest
fn from_wire( wire: DeviceRegisterPowerDomainRequest, ) -> DeviceRegisterPowerDomainRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceRegisterPowerDomainRequest> for DeviceRegisterPowerDomainRequest
impl FromWireRef<DeviceRegisterPowerDomainRequest> for DeviceRegisterPowerDomainRequest
Sourcefn from_wire_ref(
wire: &DeviceRegisterPowerDomainRequest,
) -> DeviceRegisterPowerDomainRequest
fn from_wire_ref( wire: &DeviceRegisterPowerDomainRequest, ) -> DeviceRegisterPowerDomainRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceRegisterPowerDomainRequest
impl IntoNatural for DeviceRegisterPowerDomainRequest
Sourcetype Natural = DeviceRegisterPowerDomainRequest
type Natural = DeviceRegisterPowerDomainRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceRegisterPowerDomainRequest
impl Wire for DeviceRegisterPowerDomainRequest
Sourcetype Narrowed<'de> = DeviceRegisterPowerDomainRequest
type Narrowed<'de> = DeviceRegisterPowerDomainRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>)
fn zero_padding(out_: &mut MaybeUninit<DeviceRegisterPowerDomainRequest>)
Writes zeroes to the padding for this type, if any.