#[repr(C)]pub struct DeviceRequestVoltageRequest {
pub voltage: Uint32,
}Expand description
The wire type corresponding to DeviceRequestVoltageRequest.
Fields
voltage: Uint32Trait Implementations
Sourceimpl Clone for DeviceRequestVoltageRequest
impl Clone for DeviceRequestVoltageRequest
Sourcefn clone(&self) -> DeviceRequestVoltageRequest
fn clone(&self) -> DeviceRequestVoltageRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceRequestVoltageRequest
impl Constrained for DeviceRequestVoltageRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceRequestVoltageRequest>,
_: <DeviceRequestVoltageRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceRequestVoltageRequest>, _: <DeviceRequestVoltageRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceRequestVoltageRequest
impl Debug for DeviceRequestVoltageRequest
Sourceimpl<___D> Decode<___D> for DeviceRequestVoltageRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceRequestVoltageRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceRequestVoltageRequest, ___E> for &'a DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceRequestVoltageRequest, ___E> for &'a DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceRequestVoltageRequest, ___E> for DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceRequestVoltageRequest, ___E> for DeviceRequestVoltageRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceRequestVoltageRequest, ___E> for DeviceRequestVoltageRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceRequestVoltageRequest, ___E> for DeviceRequestVoltageRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
impl FromWire<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageRequest, DeviceRequestVoltageRequest>
Sourcefn from_wire(wire: DeviceRequestVoltageRequest) -> DeviceRequestVoltageRequest
fn from_wire(wire: DeviceRequestVoltageRequest) -> DeviceRequestVoltageRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
impl FromWireRef<DeviceRequestVoltageRequest> for DeviceRequestVoltageRequest
Sourcefn from_wire_ref(
wire: &DeviceRequestVoltageRequest,
) -> DeviceRequestVoltageRequest
fn from_wire_ref( wire: &DeviceRequestVoltageRequest, ) -> DeviceRequestVoltageRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceRequestVoltageRequest
impl IntoNatural for DeviceRequestVoltageRequest
Sourcetype Natural = DeviceRequestVoltageRequest
type Natural = DeviceRequestVoltageRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceRequestVoltageRequest
impl Wire for DeviceRequestVoltageRequest
Sourcetype Narrowed<'de> = DeviceRequestVoltageRequest
type Narrowed<'de> = DeviceRequestVoltageRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceRequestVoltageRequest>)
fn zero_padding(out_: &mut MaybeUninit<DeviceRequestVoltageRequest>)
Writes zeroes to the padding for this type, if any.