#[repr(C)]pub struct DeviceRequestVoltageResponse {
pub actual_voltage: Uint32,
}Expand description
The wire type corresponding to DeviceRequestVoltageResponse.
Fields
actual_voltage: Uint32Trait Implementations
Sourceimpl Clone for DeviceRequestVoltageResponse
impl Clone for DeviceRequestVoltageResponse
Sourcefn clone(&self) -> DeviceRequestVoltageResponse
fn clone(&self) -> DeviceRequestVoltageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceRequestVoltageResponse
impl Constrained for DeviceRequestVoltageResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceRequestVoltageResponse>,
_: <DeviceRequestVoltageResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceRequestVoltageResponse>, _: <DeviceRequestVoltageResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceRequestVoltageResponse
impl Debug for DeviceRequestVoltageResponse
Sourceimpl<___D> Decode<___D> for DeviceRequestVoltageResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceRequestVoltageResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceRequestVoltageResponse, ___E> for &'a DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceRequestVoltageResponse, ___E> for &'a DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceRequestVoltageResponse, ___E> for DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceRequestVoltageResponse, ___E> for DeviceRequestVoltageResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceRequestVoltageResponse, ___E> for DeviceRequestVoltageResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceRequestVoltageResponse, ___E> for DeviceRequestVoltageResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceRequestVoltageResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceRequestVoltageResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
impl FromWire<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceRequestVoltageResponse, DeviceRequestVoltageResponse>
Sourcefn from_wire(wire: DeviceRequestVoltageResponse) -> DeviceRequestVoltageResponse
fn from_wire(wire: DeviceRequestVoltageResponse) -> DeviceRequestVoltageResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
impl FromWireRef<DeviceRequestVoltageResponse> for DeviceRequestVoltageResponse
Sourcefn from_wire_ref(
wire: &DeviceRequestVoltageResponse,
) -> DeviceRequestVoltageResponse
fn from_wire_ref( wire: &DeviceRequestVoltageResponse, ) -> DeviceRequestVoltageResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceRequestVoltageResponse
impl IntoNatural for DeviceRequestVoltageResponse
Sourcetype Natural = DeviceRequestVoltageResponse
type Natural = DeviceRequestVoltageResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceRequestVoltageResponse
impl Wire for DeviceRequestVoltageResponse
Sourcetype Narrowed<'de> = DeviceRequestVoltageResponse
type Narrowed<'de> = DeviceRequestVoltageResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceRequestVoltageResponse>)
fn zero_padding(out_: &mut MaybeUninit<DeviceRequestVoltageResponse>)
Writes zeroes to the padding for this type, if any.